@@ -1,4 +1,4 @@
-parinfo <- function(object, x, CI = 0.95, method = "Richardson", 
+parinfo <- function(object, x, CI = 0.95, tol=1e-30, method = "Richardson", 
              method.args = list(eps = 1e-04, d = 0.11, 
              zero.tol = sqrt(.Machine$double.eps/7e-07), r = 6, 
              v = 2, show.details = FALSE), side = NULL){
@@ -22,7 +22,7 @@ parinfo <- function(object, x, CI = 0.95, method = "Richardson",
                         method.args=method.args, side=side)
       D[j,] <- temp$Jacobian
     }
-    par.cov <- RSS/(n-p)*ginv( t(D) %*% D )
+    par.cov <- RSS/(n-p)*ginv( t(D) %*% D, tol=tol )
     par.se  <- c()
     for(j in 1:p){
       par.se <- c(par.se, sqrt(par.cov[j,j]))
