@@ -1,4 +1,4 @@
-skewIPEC <- function( expr, theta, x, y, tol=sqrt(.Machine$double.eps), method = "Richardson", 
+skewIPEC <- function( expr, theta, x, y, tol=1e-30, method = "Richardson", 
         method.args = list(eps = 1e-04, d = 0.11, zero.tol = sqrt(.Machine$double.eps/7e-07), 
         r = 6, v = 2, show.details = FALSE), side = NULL ) 
 {
